Software Heritage - Virtual file system
=======================================

Virtual file system to browse the
`Software Heritage <https://www.softwareheritage.org/>`_
`archive <https://archive.softwareheritage.org/>`_,
using the `FUSE <https://github.com/libfuse/libfuse>`_ framework.
